@@ -1,5 +1,6 @@
 from harlequin.components.code_editor import CodeEditor, EditorCollection
 from harlequin.components.data_catalog import DataCatalog, HarlequinTree
+from harlequin.components.debug_info import DebugInfoScreen
 from harlequin.components.error_modal import ErrorModal
 from harlequin.components.export_screen import ExportScreen, export_callback
 from harlequin.components.help_screen import HelpScreen
@@ -15,6 +16,7 @@ __all__ = [
     "export_callback",
     "HelpScreen",
     "ResultsTable",
+    "DebugInfoScreen",
     "ResultsViewer",
     "RunQueryBar",
     "DataCatalog",
